@@ -847,7 +847,7 @@ lxcSetCpusetTune(virDomainDefPtr def, virConfPtr properties)
         value->str) {
         if (virBitmapParse(value->str, 0, &nodeset, VIR_DOMAIN_CPUMASK_LEN) < 0)
             return -1;
-        if (virDomainNumatuneSet(&def->numatune,
+        if (virDomainNumatuneSet(def->numa,
                                  def->placement_mode ==
                                  VIR_DOMAIN_CPU_PLACEMENT_MODE_STATIC,
                                  VIR_DOMAIN_NUMATUNE_PLACEMENT_STATIC,
@@ -1002,7 +1002,7 @@ lxcParseConfigString(const char *config)
     if (!(properties = virConfReadMem(config, 0, VIR_CONF_FLAG_LXC_FORMAT)))
         return NULL;
 
-    if (VIR_ALLOC(vmdef) < 0)
+    if (!(vmdef = virDomainDefNew()))
         goto error;
 
     if (virUUIDGenerate(vmdef->uuid) < 0) {
