@@ -2,7 +2,7 @@
  * parallels_driver.c: core driver functions for managing
  * Parallels Cloud Server hosts
  *
- * Copyright (C) 2014 Red Hat, Inc.
+ * Copyright (C) 2014-2015 Red Hat, Inc.
  * Copyright (C) 2012 Parallels, Inc.
  *
  * This library is free software; you can redistribute it and/or
@@ -262,7 +262,9 @@ parallelsConnectOpen(virConnectPtr conn,
         return VIR_DRV_OPEN_ERROR;
     }
 
-    if ((ret = parallelsOpenDefault(conn)) != VIR_DRV_OPEN_SUCCESS)
+    if ((ret = parallelsOpenDefault(conn)) != VIR_DRV_OPEN_SUCCESS ||
+        (ret = parallelsStorageOpen(conn, flags)) != VIR_DRV_OPEN_SUCCESS ||
+        (ret = parallelsNetworkOpen(conn, flags)) != VIR_DRV_OPEN_SUCCESS)
         return ret;
 
     return VIR_DRV_OPEN_SUCCESS;
@@ -273,6 +275,9 @@ parallelsConnectClose(virConnectPtr conn)
 {
     parallelsConnPtr privconn = conn->privateData;
 
+    parallelsNetworkClose(conn);
+    parallelsStorageClose(conn);
+
     parallelsDriverLock(privconn);
     prlsdkUnsubscribeFromPCSEvents(privconn);
     virObjectUnref(privconn->caps);
@@ -951,8 +956,24 @@ parallelsDomainUndefine(virDomainPtr domain)
     return parallelsDomainUndefineFlags(domain, 0);
 }
 
+static int
+parallelsDomainHasManagedSaveImage(virDomainPtr domain, unsigned int flags)
+{
+    parallelsConnPtr privconn = domain->conn->privateData;
+    virDomainObjPtr dom = NULL;
+
+    virCheckFlags(0, -1);
+
+    dom = virDomainObjListFindByUUID(privconn->domains, domain->uuid);
+    if (dom == NULL) {
+        parallelsDomNotFoundError(domain);
+        return -1;
+    }
+
+    return 0;
+}
+
 static virHypervisorDriver parallelsDriver = {
-    .no = VIR_DRV_PARALLELS,
     .name = "Parallels",
     .connectOpen = parallelsConnectOpen,            /* 0.10.0 */
     .connectClose = parallelsConnectClose,          /* 0.10.0 */
@@ -993,6 +1014,13 @@ static virHypervisorDriver parallelsDriver = {
     .connectIsEncrypted = parallelsConnectIsEncrypted, /* 1.2.5 */
     .connectIsSecure = parallelsConnectIsSecure, /* 1.2.5 */
     .connectIsAlive = parallelsConnectIsAlive, /* 1.2.5 */
+    .domainHasManagedSaveImage = parallelsDomainHasManagedSaveImage, /* 1.2.13 */
+};
+
+static virConnectDriver parallelsConnectDriver = {
+    .hypervisorDriver = &parallelsDriver,
+    .storageDriver = &parallelsStorageDriver,
+    .networkDriver = &parallelsNetworkDriver,
 };
 
 /**
@@ -1013,11 +1041,7 @@ parallelsRegister(void)
 
     VIR_FREE(prlctl_path);
 
-    if (virRegisterHypervisorDriver(&parallelsDriver) < 0)
-        return -1;
-    if (parallelsStorageRegister())
-        return -1;
-    if (parallelsNetworkRegister())
+    if (virRegisterConnectDriver(&parallelsConnectDriver, false) < 0)
         return -1;
 
     return 0;
