@@ -179,8 +179,8 @@ int qemuMonitorTextAddNetdev(qemuMonitorPtr mon,
 int qemuMonitorTextRemoveNetdev(qemuMonitorPtr mon,
                                 const char *alias);
 
-int qemuMonitorTextGetPtyPaths(qemuMonitorPtr mon,
-                               virHashTablePtr paths);
+int qemuMonitorTextGetChardevInfo(qemuMonitorPtr mon,
+                                  virHashTablePtr info);
 
 int qemuMonitorTextAttachPCIDiskController(qemuMonitorPtr mon,
                                            const char *bus,
@@ -228,7 +228,7 @@ int qemuMonitorTextScreendump(qemuMonitorPtr mon, const char *file);
 
 int qemuMonitorTextSetLink(qemuMonitorPtr mon,
                            const char *name,
-                           enum virDomainNetInterfaceLinkState state);
+                           virDomainNetInterfaceLinkState state);
 
 int qemuMonitorTextOpenGraphics(qemuMonitorPtr mon,
                                 const char *protocol,
