@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2014 Red Hat, Inc.
+ * Copyright (C) 2009-2015 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -83,6 +83,13 @@ virNetDevBandwidthSet(const char *ifname,
         return -1;
     }
 
+    if (!ifname) {
+        virReportError(VIR_ERR_OPERATION_UNSUPPORTED, "%s",
+                       _("Unable to set bandwidth for interface because "
+                         "device name is unknown"));
+        return -1;
+    }
+
     virNetDevBandwidthClear(ifname);
 
     if (bandwidth->in && bandwidth->in->average) {
@@ -268,6 +275,9 @@ virNetDevBandwidthClear(const char *ifname)
     int dummy; /* for ignoring the exit status */
     virCommandPtr cmd = NULL;
 
+    if (!ifname)
+       return 0;
+
     cmd = virCommandNew(TC);
     virCommandAddArgList(cmd, "qdisc", "del", "dev", ifname, "root", NULL);
 
