@@ -1,6 +1,6 @@
 /*---------------------------------------------------------------------------*/
 /*
- * Copyright (C) 2011-2012 Red Hat, Inc.
+ * Copyright (C) 2011-2015 Red Hat, Inc.
  * Copyright 2010, diateam (www.diateam.net)
  * Copyright (C) 2013. Doug Goldstein <cardoe@cardoe.com>
  *
@@ -1195,10 +1195,33 @@ vmwareConnectListAllDomains(virConnectPtr conn,
     return ret;
 }
 
+static int
+vmwareDomainHasManagedSaveImage(virDomainPtr dom, unsigned int flags)
+{
+    struct vmware_driver *driver = dom->conn->privateData;
+    virDomainObjPtr obj;
+    int ret = -1;
+
+    virCheckFlags(0, -1);
+
+    vmwareDriverLock(driver);
+    obj = virDomainObjListFindByUUID(driver->domains, dom->uuid);
+    vmwareDriverUnlock(driver);
+    if (!obj) {
+        virReportError(VIR_ERR_NO_DOMAIN, NULL);
+        goto cleanup;
+    }
+    ret = 0;
+
+ cleanup:
+    if (obj)
+        virObjectUnlock(obj);
+    return ret;
+}
 
 
-static virHypervisorDriver vmwareDriver = {
-    .no = VIR_DRV_VMWARE,
+
+static virHypervisorDriver vmwareHypervisorDriver = {
     .name = "VMWARE",
     .connectOpen = vmwareConnectOpen, /* 0.8.7 */
     .connectClose = vmwareConnectClose, /* 0.8.7 */
@@ -1234,12 +1257,16 @@ static virHypervisorDriver vmwareDriver = {
     .domainIsActive = vmwareDomainIsActive, /* 0.8.7 */
     .domainIsPersistent = vmwareDomainIsPersistent, /* 0.8.7 */
     .connectIsAlive = vmwareConnectIsAlive, /* 0.9.8 */
+    .domainHasManagedSaveImage = vmwareDomainHasManagedSaveImage, /* 1.2.13 */
+};
+
+static virConnectDriver vmwareConnectDriver = {
+    .hypervisorDriver = &vmwareHypervisorDriver,
 };
 
 int
 vmwareRegister(void)
 {
-    if (virRegisterHypervisorDriver(&vmwareDriver) < 0)
-        return -1;
-    return 0;
+    return virRegisterConnectDriver(&vmwareConnectDriver,
+                                    false);
 }
