@@ -82,6 +82,9 @@ char *virtTestLogContentAndReset(void);
 
 void virtTestQuiesceLibvirtErrors(bool always);
 
+void virtTestCounterReset(const char *prefix);
+const char *virtTestCounterNext(void);
+
 int virtTestMain(int argc,
                  char **argv,
                  int (*func)(void));
